/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.sinfo.flowdepthminmax;

import org.dive4elements.river.artifacts.sinfo.common.AbstractSInfoResultRow;

/**
 * Part of {@link FlowDepthMinMaxCalculationResult} which represents one calculated row of flow depth data.
 *
 * @author Gernot Belger
 */
final class FlowDepthMinMaxRow extends AbstractSInfoResultRow {
    private static final long serialVersionUID = 1L;

    private final double station;

    private final double minFlowDepth;

    private final double maxFlowDepth;

    private final double waterlevel;

    private final double discharge;

    private final double meanBedHeight;

    private final String soundingLabel;

    public FlowDepthMinMaxRow(final double station, final double minFlowDepth, final double maxFlowDepth, final double waterlevel, final double discharge,
            final String waterlevelLabel, final String gauge, final double meanBedHeight, final String soundingLabel, final String location) {

        super(waterlevelLabel, gauge, location);

        this.station = station;
        this.minFlowDepth = minFlowDepth;
        this.maxFlowDepth = maxFlowDepth;
        this.waterlevel = waterlevel;
        this.discharge = discharge;
        this.meanBedHeight = meanBedHeight;
        this.soundingLabel = soundingLabel;
    }

    public String getSoundageLabel() {
        return this.soundingLabel;
    }

    public double getStation() {
        return this.station;
    }

    public double getMinFlowDepth() {
        return this.minFlowDepth;
    }

    public double getMaxFlowDepth() {
        return this.maxFlowDepth;
    }

    public double getWaterlevel() {
        return this.waterlevel;
    }

    public double getDischarge() {
        return this.discharge;
    }

    public double getMeanBedHeight() {
        return this.meanBedHeight;
    }

    public String getSoundingLabel() {
        return this.soundingLabel;
    }
}